<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 * 
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/* Loads the theme options init. */
require_once( trailingslashit( get_template_directory() ) . 'includes/theme-options.php' );

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since  1.0.0
 * @access public
 */
if ( ! isset( $content_width ) )
	$content_width = 630;

/* Do theme setup on the 'after_setup_theme' hook. */
add_action( 'after_setup_theme', 'tj_setup' );

/* Loads function libraries. */
add_action( 'after_setup_theme', 'tj_load_libraries', 11 );

/**
 * Theme setup function. This function adds support for theme features and defines the default theme
 * actions and filters.
 * 
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Plugin_API/Action_Reference/after_setup_theme
 */
function tj_setup() {

	/* Setup the custom menu. */
	register_nav_menus(
		array(
			'primary-nav' => __( 'Primary Nav', 'junkie' )
		)
	);

	/* Enable Post Thumbnails support. */
	add_theme_support( 'post-thumbnails' );

	/* Setup the WordPress core custom background feature. */
	add_theme_support( 
		'custom-background',
		array(
			'default-color' => 'ffffff',
		)
	);

	/* Editor styles. */
	add_editor_style( 'editor-style.css' );

	/* Add default posts and comments RSS feed links to head. */
	add_theme_support( 'automatic-feed-links' );

	/* Enable support for HTML5 markup. */
	add_theme_support(
		'html5',
		array(
			'comment-list',
			'search-form',
			'comment-form',
			'gallery',
		)
	);

	/* Remove gallery inline style */
	add_filter( 'use_default_gallery_style', '__return_false' );

	/* Add custom image sizes. */
	add_action( 'init', 'tj_add_image_sizes' );

	/* Add custom image sizes custom name. */
	add_filter( 'image_size_names_choose', 'tj_custom_name_image_sizes' );

}

/**
 * Loads function libraries.
 *
 * @since  1.0.0
 * @access public
 */
function tj_load_libraries() {

	/* Loads the custom sidebars. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/sidebar-init.php' );

	/* Loads the custom functions. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/custom-functions.php' );

	/* Loads the theme functions. */
	require_once( trailingslashit( get_template_directory() ) . 'functions/theme_functions.php' ); 
	
	/* Loads the admin funtions. */
	require_once( trailingslashit( get_template_directory() ) . 'functions/admin_functions.php' );

	/* Loads the custom meta boxes. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/theme-posttypes.php');

	/* Loads the custom meta boxes. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/theme-postmeta.php');

	/* Enqueue styles and scripts. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/enqueue.php');

	/* Loads custom functions. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/functions.php');

	/* Loads custom template tags. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/template-tags.php');

	/* Loads custom helper functions. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/helpers.php');

	/* Loads custom widgets. */
	require_once( trailingslashit( get_template_directory() ) . 'includes/theme-widgets.php');

}

/**
 * Adds custom image sizes.
 *
 * @since  1.0.0
 * @access public
 * @link   http://codex.wordpress.org/Function_Reference/add_image_size
 */
function tj_add_image_sizes() {
	add_image_size( 'scroller-featured'    , 640, 250, true );
	add_image_size( 'scroller-portfolio'   , 225, 172, true );
	add_image_size( 'scroller-blog'        , 64 , 64 , true );
	add_image_size( 'scroller-portfolio-2' , 465, 370, true );
	add_image_size( 'scroller-portfolio-3' , 300, 200, true );
	add_image_size( 'scroller-portfolio-4' , 217, 163, true );
	add_image_size( 'scroller-gallery'     , 630, 600, true );
}

/**
 * Adds custom image sizes custom name.
 *
 * @since  1.0.0
 * @access public
 */
function tj_custom_name_image_sizes( $sizes ) {
    $sizes['scroller-featured']    = __( 'Featured Thumbnail'  , 'junkie' );
    $sizes['scroller-portfolio']   = __( 'Portfolio Thumbnail' , 'junkie' );
    $sizes['scroller-blog']        = __( 'Blog Thumbnail'      , 'junkie' );
    $sizes['scroller-portfolio-2'] = __( 'Portfolio 2 Columns' , 'junkie' );
    $sizes['scroller-portfolio-3'] = __( 'Portfolio 3 Columns' , 'junkie' );
    $sizes['scroller-portfolio-4'] = __( 'Portfolio 4 Columns' , 'junkie' );
    $sizes['scroller-gallery']     = __( 'Portfolio Galery'    , 'junkie' );
 
    return $sizes;
}

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'plugins/plugins.php';

// MailOptin integration
require get_template_directory() . '/includes/mailoptin.php';
